==> fusionX-0.0.9.tar.gz: fusionX-0.0.9/setup.py <==

from setuptools import setup, find_packages

install_deps = ['numpy>=1.20.0', 'opencv-python>= 4.8.1.78', 'pickle5>=0.0.12']
VERSION = 'V0.0.9'
DESCRIPTION = 'fusionX'

# Setting up
setup(
    name="fusionX",
    version=VERSION,
    author="Bar Ben David, Suman Khan",
    author_email="FusionX_pipeline@hotmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description="""
    A deep learning pipeline for cell-cell fusion analysis

    Authors: Bar Ben David, Suman Khan
    Email: FusionX_pipeline@hotmail.com
    """,

    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=install_deps,
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    entry_points={
        'console_scripts': [
            'run_after_install = fusionX:sayhi',
        ],
    },
)

#######################################################
#from setuptools import setup, find_packages


#install_deps = ['numpy>=1.20.0', 'opencv-python>= 4.8.1.78', 'pickle5>=0.0.12']
#VERSION = 'V0.0.4'
#DESCRIPTION = 'fusionX'

# Setting up
#setup(
#    name="fusionX",
#    version=VERSION,
#    author="Bar Ben David, Suman Khan",
#    author_email="<FusionX_pipeline@hotmail.com>",
#    description=DESCRIPTION,
#    long_description_content_type="text/markdown",
#    long_description="""
#    A deep learning pipeline for cell-cell fusion analysis

#    Authors: Bar Ben David , Suman Khan
#    Email: FusionX_pipeline@hotmail.com
#    """
#,
# 
#    packages=find_packages(),
#    install_requires=install_deps,
#    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
#    classifiers=[
#        "Development Status :: 1 - Planning",
#        "Intended Audience :: Developers",
#        "Programming Language :: Python :: 3",
#        "Operating System :: Unix",
#        "Operating System :: MacOS :: MacOS X",
#        "Operating System :: Microsoft :: Windows",
#    ]
#)

==> fusionX-0.1.0.tar.gz: fusionX-0.1.0/setup.py <==

from setuptools import setup, find_packages

install_deps = ['numpy>=1.20.0', 'opencv-python>= 4.8.1.78']
VERSION = 'V0.1.0'
DESCRIPTION = 'fusionX'

# Setting up
setup(
    name="fusionX",
    version=VERSION,
    author="Bar Ben David, Suman Khan",
    author_email="FusionX_pipeline@hotmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description="""
    A deep learning pipeline for cell-cell fusion analysis

    Authors: Bar Ben David, Suman Khan
    Email: FusionX_pipeline@hotmail.com
    """,

    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=install_deps,
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    entry_points={
        'console_scripts': [
            'run_after_install = fusionX.__init__:main',
        ],
    },
)

#######################################################
#from setuptools import setup, find_packages


#install_deps = ['numpy>=1.20.0', 'opencv-python>= 4.8.1.78', 'pickle5>=0.0.12']
#VERSION = 'V0.1.0'
#DESCRIPTION = 'fusionX'

# Setting up
#setup(
#    name="fusionX",
#    version=VERSION,
#    author="Bar Ben David, Suman Khan",
#    author_email="<FusionX_pipeline@hotmail.com>",
#    description=DESCRIPTION,
#    long_description_content_type="text/markdown",
#    long_description="""
#    A deep learning pipeline for cell-cell fusion analysis

#    Authors: Bar Ben David , Suman Khan
#    Email: FusionX_pipeline@hotmail.com
#    """
#,
# 
#    packages=find_packages(),
#    install_requires=install_deps,
#    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
#    classifiers=[
#        "Development Status :: 1 - Planning",
#        "Intended Audience :: Developers",
#        "Programming Language :: Python :: 3",
#        "Operating System :: Unix",
#        "Operating System :: MacOS :: MacOS X",
#        "Operating System :: Microsoft :: Windows",
#    ]
#)
